import { jsx } from 'react/jsx-runtime';
import cx from 'clsx';
import hljs from 'highlight.js';
import { factory, useProps, useStyles, Box } from '@raikou/core';
import { CodeHighlightCodeStyle } from './CodeHighlight.css.mjs';
import { CodeHighlightThemeStyle } from './CodeHighlight.theme.css.mjs';

const defaultProps = {
  language: "tsx"
};
const InlineCodeHighlight = factory((_props, ref) => {
  const props = useProps("InlineCodeHighlight", defaultProps, _props);
  const { classNames, className, style, styles, unstyled, vars, code, language, ...others } = props;
  const getStyles = useStyles({
    name: "InlineCodeHighlight",
    props,
    classes: {
      code: cx(CodeHighlightCodeStyle, CodeHighlightThemeStyle)
    },
    className,
    style,
    classNames,
    styles,
    unstyled,
    rootSelector: "code"
  });
  const highlighted = hljs.highlight(code.trim(), { language }).value;
  return /* @__PURE__ */ jsx(
    Box,
    {
      ...getStyles("code"),
      component: "code",
      ref,
      ...others,
      dangerouslySetInnerHTML: { __html: highlighted }
    }
  );
});
InlineCodeHighlight.displayName = "@raikou/core/InlineCodeHighlight";

export { InlineCodeHighlight };
//# sourceMappingURL=InlineCodeHighlight.mjs.map
